#!/bin/bash
# Syncplify.me AFT! installation script
# Fresh install functions


do_fresh_install() {
	echo

	# exesudo ensure_ek

	if service_exists syncplify-me-aft; then
	  echo "AFT! service found, stopping it..."
	  sudo systemctl disable syncplify-me-aft
	  sudo systemctl stop syncplify-me-aft
	  sleep 0.5
	  echo "AFT! service stopped"
	fi

	echo "Copying main executable file..."
	sudo cp -p ./bin/syncplify-me-aft /usr/bin/syncplify-me-aft
	sudo chmod +x /usr/bin/syncplify-me-aft

	echo "Copying service descriptor..."
	sudo cp -p ./svc/syncplify-me-aft.service /etc/systemd/system/syncplify-me-aft.service
	sudo chmod 644 /etc/systemd/system/syncplify-me-aft.service

	if file_exists "/etc/xdg/Syncplify.me/AFTv1/cfg/init" ; then
	  echo "Existing configuration found, erasing it..."
	  sudo rm -r /etc/xdg/Syncplify.me/AFTv1
	fi
	
	echo "Ensuring directory structure is correct..."
	sudo mkdir -p /etc/xdg/Syncplify.me/AFTv1/certs
	sudo mkdir -p /etc/xdg/Syncplify.me/AFTv1/modules

	echo "Verifying existence of EK value..."
	if ! file_exists /etc/xdg/Syncplify.me/AFTv1/env.conf
	then
	  exesudo ensure_ek_systemd
	else
	  echo "EK found, kept existing one"
	fi

	echo "Deploying management interface..."
	sudo rm -r -f /etc/xdg/Syncplify.me/AFTv1/manage
	sudo cp -r ./manage /etc/xdg/Syncplify.me/AFTv1/manage
	
	echo "Deploying modules..."
	sudo rm -r -f /etc/xdg/Syncplify.me/AFTv1/modules
	sudo cp -r ./manage /etc/xdg/Syncplify.me/AFTv1/modules

	echo "Installing self-signed digital certificates..."
	sudo cp -r ./certs/server.key /etc/xdg/Syncplify.me/AFTv1/certs/server.key
	echo "Self-signed certificate key installed"
	sudo cp -r ./certs/server.crt /etc/xdg/Syncplify.me/AFTv1/certs/server.crt
	echo "Self-signed certificate installed"

	echo "Ensuring availability of setup shell scripts..."
	sudo mkdir -p /usr/bin/syncplify-me-aft-setup
	sudo cp -p ./setup.sh /usr/bin/syncplify-me-aft-setup/setup.sh
	sudo cp -r ./functions /usr/bin/syncplify-me-aft-setup/functions

	echo "Starting AFT! service..."
	sudo systemctl start syncplify-me-aft
	sudo systemctl enable syncplify-me-aft
	sleep 0.5
	echo "DONE"
	echo
	echo "AFT! is avilable at https://127.0.0.1:44399/"
	echo
	xdg-open "https://127.0.0.1:44399/"
}
